module FWToolkit
  module Executable

    class ThorRunner
      def run(command, config={})
        Thor::Actions::run(command, config)
      end

      def report_error(command, command_output)
        command_output.gsub!(/e\[\d+m/, '') #Stripping colors
        say "An error has occured while running: \"#{command}\"", :red
        say 'Command output:'
        raise Thor::Error, "\n***\n#{command_output}***"
      end
    end

    class CliRunner
      def run(command, config={})
        `#{command}`
      end

      def report_error(command, command_output)
        command_output.gsub!(/e\[\d+m/, '')
        puts "An error has occured while running: \"#{command}\"", :red
        puts 'Command output:'
        raise "\n***\n#{command_output}***"
      end
 
    end

    def self.runner=(runner)
      @@runner = runner
    end

    def run(command, options = {})
      cmd_output = @@runner.run command, options
      @@runner.report_error(command, cmd_output) if options[:raise_errors] && !$?.success?
    end

    def run!(command, options = {})
      config.merge!({ :raise_errors => true })
      run command config
    end
  end
end
