require 'rake'
require 'xcodebuild'
require 'fwtoolkit/rake/tasks/config'
require 'fwtoolkit/projectfile'

module FWToolkit
  module Rake
    class XcodeTask < ::Rake::Task
      include ::Rake::DSL if defined?(::Rake::DSL)
      include Config
      def initialize(&block)
        yield self if block_given?
        define_task
      end


      private

      def define_task
        namespace :xcode do
          Projectfile.load! projectfile_path
          Config.load!

          XcodeBuild::Tasks::BuildTask.new :debug do |t|
            t.invoke_from_within = '.'
            t.configuration = "Debug"
            t.sdk = "iphonesimulator"
            t.workspace = Projectfile.xcode_workspace
            t.scheme = Projectfile.xcode_scheme
            t.formatter = XcodeBuild::Formatters::ProgressFormatter.new
            t.add_build_setting 'CONFIGURATION_BUILD_DIR', Config.artifacts_tmp_dir
          end

          XcodeBuild::Tasks::BuildTask.new :testing do |t|
            t.invoke_from_within = '.'
            t.configuration = "Debug"
            t.sdk = "iphoneos"
            t.workspace = Projectfile.xcode_workspace
            t.scheme = Projectfile.xcode_scheme
            t.formatter = XcodeBuild::Formatters::ProgressFormatter.new
            t.add_build_setting 'CONFIGURATION_BUILD_DIR', Config.artifacts_tmp_dir
          end

          XcodeBuild::Tasks::BuildTask.new :release do |t|
            t.invoke_from_within = '.'
            t.configuration = "Release"
            t.sdk = "iphoneos"
            t.workspace = Projectfile.xcode_workspace
            t.scheme = Projectfile.xcode_scheme
            t.formatter = XcodeBuild::Formatters::ProgressFormatter.new
            t.add_build_setting 'CONFIGURATION_BUILD_DIR', Config.artifacts_tmp_dir
          end

          namespace :ci do
            XcodeBuild::Tasks::BuildTask.new :testing do |t|
              t.invoke_from_within = '.'
              t.configuration = "Debug"
              t.sdk = "iphonesimulator"
              t.workspace = Projectfile.xcode_workspace
              t.scheme = Projectfile.xcode_scheme
              t.formatter = XcodeBuild::Formatters::ProgressFormatter.new
              t.add_build_setting 'CONFIGURATION_BUILD_DIR', Config.artifacts_tmp_dir
            end
          end
        end
      end
    end
  end
end
